@@ -25,7 +25,8 @@ from ..amqp import MessageCtx, get_message_ctx
 from ..types import AMQPBody, Symbol
 from .client import StreamsClient, streams_client, connection
 from .offset import Offset, OffsetType
-from ._client import Publisher, PublisherBatch, PublisherConstr, Subscriber
+from ._client import Publisher, PublisherBatch, PublisherBatchMem, \
+    PublisherConstr, Subscriber
 
 __all__ = [
     'connection',
@@ -34,7 +35,8 @@ __all__ = [
     'StreamsClient', 'streams_client', 'Offset', 'OffsetType',
 
     # publisher and subscriber api
-    'Publisher', 'PublisherBatch', 'PublisherConstr', 'Subscriber',
+    'Publisher', 'PublisherBatch', 'PublisherBatchMem', 'PublisherConstr',
+    'Subscriber',
 
     'AMQPBody', 'Symbol',
 
