@@ -116,8 +116,7 @@ class StreamsClient(ConnectionManager[RabbitMQStreamsProtocol]):
         """
         Perform connection or reconnection to RabbitMQ Streams broker.
 
-        Recreate existing publishers. See `_read_stream` for subscriber
-        recreation.
+        Recreate existing publishers and subscribers.
         """
         cinfo = self._cinfo
         await protocol.connection_handshake(
