@@ -85,8 +85,6 @@ PEER_PROPERTIES = {
         ' see https://gitlab.com/wrobell/rbfly',
 }
 
-DEFAULT_CREDIT = 10
-
 # pylint: disable=no-member
 REQUESTS_KEYS = {
     const.RESPONSE_KEY_PEER_PROPERTIES,    # type: ignore
@@ -146,7 +144,6 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         self.transport = Option[asyncio.Transport]()
         self.decoder = codec.FrameDecoder()
         self.encoder = codec.Encoder(self.frame_size)
-        self.credit = DEFAULT_CREDIT
 
         self._loop = asyncio.get_running_loop()
         self._requests: Requests = {}
@@ -336,7 +333,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         )
 
         task = self._loop.create_future()
-        data = codec.encode_subscribe(sid, stream, offset, self.credit)
+        data = codec.encode_subscribe(sid, stream, offset, const.DEFAULT_CREDIT)
         self._subscriptions[sid] = ReceivedMessages(task, value, MessageQueue(), amqp)
         return await self.send_request(const.KEY_SUBSCRIBE, data)
 
@@ -350,6 +347,9 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         task = rm.task
         queue = rm.queue
         if task.done() and queue:
+            # because of subscription credit, the message queue can get
+            # updated already, do not create a new task, just return the
+            # messages
             return queue
         elif task.done():
             task = self._loop.create_future()
@@ -477,7 +477,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         )
         return tp.cast(int, msg_id)
 
-    def send_credit(self, subscription_id: int) -> None:
+    def send_credit(self, subscription_id: int, credit: int) -> None:
         """
         Update message delivery credit for the subscription.
 
@@ -485,10 +485,9 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         sent and no response is expected from RabbitMQ Streams broker.
 
         :param subscription_id: Subscription id.
+        :param credit: Amount of credit to send.
         """
-        # TODO: can we use more credit and then shutdown cleanly?
-        self.credit = 1
-        data = codec.encode_credit(subscription_id, 1)
+        data = codec.encode_credit(subscription_id, credit)
         self.send_frame(data)
 
     def store_offset(self, stream: str, reference: str, offset: Offset) -> None:
@@ -765,10 +764,6 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
             task = rm.task
             codec.decode_messages(data, offset + 1, rm.offset, rm.queue, rm.amqp)
 
-            self.credit =- 1
-            if self.credit <= 0:
-                self.send_credit(sid)
-
             if not task.done():
                 task.set_result(None)
         else:
