@@ -18,13 +18,22 @@
 #
 
 """
-Basic types for RabbitMQ Streams API.
+Basic types for RabbitMQ Streams implementation.
 """
 
+import typing as tp
 from collections import deque
 
 from ..amqp import MessageCtx
 
 MessageQueue = deque[MessageCtx]
 
+class PublishError(tp.NamedTuple):
+    """
+    Error information received from RabbitMQ Streams broker after
+    publishing a message.
+    """
+    publisher_id: int
+    errors: tuple[tuple[int, int], ...]
+
 # vim: sw=4:et:ai
