@@ -80,9 +80,14 @@ DATA = (
     ),
     # nested map
     (
-        MessageCtx({'a': 1, 'b': {'a': 1, 'b': 2}}),  # type: ignore
+        MessageCtx({'a': 1, 'b': {'a': 1, 'b': 2}}),
         b'\x00Sw\xd1\x00\x00\x00\x24\x00\x00\x00\x04\xa1\x01a\x71\x00\x00\x00\x01\xa1\x01b\xd1\x00\x00\x00\x10\x00\x00\x00\x04\xa1\x01a\x71\x00\x00\x00\x01\xa1\x01b\x71\x00\x00\x00\x02',
     ),
+    # a map with binary data
+    (
+        MessageCtx({b'ab': b'xy'}),
+        b'\x00Sw\xd1\x00\x00\x00\x08\x00\x00\x00\x02\xa0\x02ab\xa0\x02xy',
+    ),
     # list
     (
         MessageCtx(['a', 1, 'b', 2]),
@@ -90,9 +95,14 @@ DATA = (
     ),
     # nested list
     (
-        MessageCtx(['a', 1, 'b', ['a', 1, 'b', 2]]),  # type: ignore
+        MessageCtx(['a', 1, 'b', ['a', 1, 'b', 2]]),
         b'\x00Sw\xd0\x00\x00\x00\x24\x00\x00\x00\x04\xa1\x01a\x71\x00\x00\x00\x01\xa1\x01b\xd0\x00\x00\x00\x10\x00\x00\x00\x04\xa1\x01a\x71\x00\x00\x00\x01\xa1\x01b\x71\x00\x00\x00\x02',
     ),
+    # a list with binary data
+    (
+        MessageCtx([255, b'abc']),
+        b'\x00Sw\xd0\x00\x00\x00\n\x00\x00\x00\x02q\x00\x00\x00\xff\xa0\x03abc',
+    )
 )
 
 # decoding of AMQP types, which are not encoded by rbfly
