@@ -42,26 +42,38 @@ DELIVERED_DATA = (  # type: ignore
     (
         DELIVERED_MSG_DATA_1,
         None,
-        [MessageCtx(b'3210000123', stream_offset=0, stream_timestamp=1636891987)]
+        [
+            MessageCtx(
+                b'3210000123',
+                stream_offset=0,
+                stream_timestamp=1636891987.216
+            )
+        ]
     ),
     (
         DELIVERED_MSG_DATA_1,
         0,
-        [MessageCtx(b'3210000123', stream_offset=0, stream_timestamp=1636891987)]
-    ),
+        [
+            MessageCtx(
+                b'3210000123',
+                stream_offset=0,
+                stream_timestamp=1636891987.216
+            )
+        ]
+        ),
     (DELIVERED_MSG_DATA_1, 1, []),  # request offset > 0
     (
         DELIVERED_MSG_DATA_2,
         974,
         [
-            MessageCtx(b'0000000064', stream_offset=974, stream_timestamp=1636900128),
-            MessageCtx(b'0000000065', stream_offset=975, stream_timestamp=1636900128),
+            MessageCtx(b'0000000064', stream_offset=974, stream_timestamp=1636900128.714),
+            MessageCtx(b'0000000065', stream_offset=975, stream_timestamp=1636900128.714),
         ],
     ),
     (
         DELIVERED_MSG_DATA_2,
         975,
-        [MessageCtx(b'0000000065', stream_offset=975, stream_timestamp=1636900128)]
+        [MessageCtx(b'0000000065', stream_offset=975, stream_timestamp=1636900128.714)]
     ),
 )
 
